#
# This file is part of App-SpreadRevolutionaryDate
#
# This software is Copyright (c) 2019 by Gérald Sédrati-Dinet.
#
# This is free software, licensed under:
#
#   The GNU General Public License, Version 3, June 2007
#

# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.010.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Spread date and time from Revolutionary (Republican) Calendar on Twitter, Mastodon and Freenode.",
  "dist_author" => [
    "G\x{e9}rald S\x{e9}drati-Dinet <gibus\@cpan.org>"
  ],
  "dist_name" => "App-SpreadRevolutionaryDate",
  "dist_version" => "0.02",
  "license" => "gpl",
  "module_name" => "App::SpreadRevolutionaryDate",
  "recursive_test_files" => 1,
  "requires" => {
    "AppConfig" => 0,
    "Bot::BasicBot" => 0,
    "DateTime::Calendar::FrenchRevolutionary" => 0,
    "Mastodon::Client" => 0,
    "Net::Twitter::Lite::WithAPIv1_1" => 0,
    "open" => 0,
    "parent" => 0,
    "strict" => 0,
    "utf8" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/spread-revolutionary-date"
  ],
  "test_requires" => {
    "File::Find" => 0,
    "File::Temp" => 0,
    "Test::More" => 0,
    "Test::NoWarnings" => 0
  }
);


my %fallback_build_requires = (
  "File::Find" => 0,
  "File::Temp" => 0,
  "Module::Build" => "0.28",
  "Test::More" => 0,
  "Test::NoWarnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
