use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::NoTabs 0.15

use Test::More 0.88;
use Test::NoTabs;

my @files = (
    'bin/spread-revolutionary-date',
    'lib/App/SpreadRevolutionaryDate.pm',
    'lib/App/SpreadRevolutionaryDate/Config.pm',
    'lib/App/SpreadRevolutionaryDate/Freenode.pm',
    'lib/App/SpreadRevolutionaryDate/Freenode/Bot.pm',
    'lib/App/SpreadRevolutionaryDate/Mastodon.pm',
    'lib/App/SpreadRevolutionaryDate/Twitter.pm',
    't/00-compile.t',
    't/config.t',
    't/objects.t'
);

notabs_ok($_) foreach @files;
done_testing;
